Class Lambda2Configuration

java.lang.Object
org.apache.camel.component.aws2.lambda.Lambda2Configuration
All Implemented Interfaces:
Cloneable, org.apache.camel.component.aws.common.AwsCommonConfiguration

@UriParams public class Lambda2Configuration extends Object implements Cloneable, org.apache.camel.component.aws.common.AwsCommonConfiguration
  • Constructor Details

    • Lambda2Configuration

      public Lambda2Configuration()
  • Method Details

    • getAwsLambdaClient

      public software.amazon.awssdk.services.lambda.LambdaClient getAwsLambdaClient()
    • setAwsLambdaClient

      public void setAwsLambdaClient(software.amazon.awssdk.services.lambda.LambdaClient awsLambdaClient)
      To use an existing configured AwsLambdaClient client
    • getAccessKey

      public String getAccessKey()
      Specified by:
      getAccessKey in interface org.apache.camel.component.aws.common.AwsCommonConfiguration
    • setAccessKey

      public void setAccessKey(String accessKey)
      Amazon AWS Access Key
    • getSecretKey

      public String getSecretKey()
      Specified by:
      getSecretKey in interface org.apache.camel.component.aws.common.AwsCommonConfiguration
    • setSecretKey

      public void setSecretKey(String secretKey)
      Amazon AWS Secret Key
    • getSessionToken

      public String getSessionToken()
      Specified by:
      getSessionToken in interface org.apache.camel.component.aws.common.AwsCommonConfiguration
    • setSessionToken

      public void setSessionToken(String sessionToken)
      Amazon AWS Session Token used when the user needs to assume an IAM role
    • getRegion

      public String getRegion()
      Specified by:
      getRegion in interface org.apache.camel.component.aws.common.AwsCommonConfiguration
    • setRegion

      public void setRegion(String region)
      The region in which the Lambda client needs to work. When using this parameter, the configuration will expect the lowercase name of the region (for example, ap-east-1) You'll need to use the name Region.EU_WEST_1.id()
    • getOperation

      public Lambda2Operations getOperation()
    • setOperation

      public void setOperation(Lambda2Operations operation)
      The operation to perform. It can be listFunctions, getFunction, createFunction, deleteFunction or invokeFunction
    • getProxyProtocol

      public software.amazon.awssdk.core.Protocol getProxyProtocol()
      Specified by:
      getProxyProtocol in interface org.apache.camel.component.aws.common.AwsCommonConfiguration
    • setProxyProtocol

      public void setProxyProtocol(software.amazon.awssdk.core.Protocol proxyProtocol)
      To define a proxy protocol when instantiating the Lambda client
    • getProxyHost

      public String getProxyHost()
      Specified by:
      getProxyHost in interface org.apache.camel.component.aws.common.AwsCommonConfiguration
    • setProxyHost

      public void setProxyHost(String proxyHost)
      To define a proxy host when instantiating the Lambda client
    • getProxyPort

      public Integer getProxyPort()
      Specified by:
      getProxyPort in interface org.apache.camel.component.aws.common.AwsCommonConfiguration
    • setProxyPort

      public void setProxyPort(Integer proxyPort)
      To define a proxy port when instantiating the Lambda client
    • isPojoRequest

      public boolean isPojoRequest()
    • setPojoRequest

      public void setPojoRequest(boolean pojoRequest)
      If we want to use a POJO request as body or not
    • isTrustAllCertificates

      public boolean isTrustAllCertificates()
      Specified by:
      isTrustAllCertificates in interface org.apache.camel.component.aws.common.AwsCommonConfiguration
    • setTrustAllCertificates

      public void setTrustAllCertificates(boolean trustAllCertificates)
      If we want to trust all certificates in case of overriding the endpoint
    • isOverrideEndpoint

      public boolean isOverrideEndpoint()
      Specified by:
      isOverrideEndpoint in interface org.apache.camel.component.aws.common.AwsCommonConfiguration
    • setOverrideEndpoint

      public void setOverrideEndpoint(boolean overrideEndpoint)
      Set the need for overriding the endpoint. This option needs to be used in combination with the uriEndpointOverride option
    • getUriEndpointOverride

      public String getUriEndpointOverride()
      Specified by:
      getUriEndpointOverride in interface org.apache.camel.component.aws.common.AwsCommonConfiguration
    • setUriEndpointOverride

      public void setUriEndpointOverride(String uriEndpointOverride)
      Set the overriding uri endpoint. This option needs to be used in combination with overrideEndpoint option
    • setUseDefaultCredentialsProvider

      public void setUseDefaultCredentialsProvider(Boolean useDefaultCredentialsProvider)
      Set whether the Lambda client should expect to load credentials through a default credentials provider or to expect static credentials to be passed in.
    • isUseDefaultCredentialsProvider

      public boolean isUseDefaultCredentialsProvider()
      Specified by:
      isUseDefaultCredentialsProvider in interface org.apache.camel.component.aws.common.AwsCommonConfiguration
    • isUseProfileCredentialsProvider

      public boolean isUseProfileCredentialsProvider()
      Specified by:
      isUseProfileCredentialsProvider in interface org.apache.camel.component.aws.common.AwsCommonConfiguration
    • setUseProfileCredentialsProvider

      public void setUseProfileCredentialsProvider(boolean useProfileCredentialsProvider)
      Set whether the Lambda client should expect to load credentials through a profile credentials provider.
    • isUseSessionCredentials

      public boolean isUseSessionCredentials()
      Specified by:
      isUseSessionCredentials in interface org.apache.camel.component.aws.common.AwsCommonConfiguration
    • setUseSessionCredentials

      public void setUseSessionCredentials(boolean useSessionCredentials)
      Set whether the Lambda client should expect to use Session Credentials. This is useful in a situation in which the user needs to assume an IAM role for doing operations in Lambda.
    • getProfileCredentialsName

      public String getProfileCredentialsName()
      Specified by:
      getProfileCredentialsName in interface org.apache.camel.component.aws.common.AwsCommonConfiguration
    • setProfileCredentialsName

      public void setProfileCredentialsName(String profileCredentialsName)
      If using a profile credentials provider, this parameter will set the profile name
    • copy

      public Lambda2Configuration copy()