Class Lambda2Configuration
java.lang.Object
org.apache.camel.component.aws2.lambda.Lambda2Configuration
- All Implemented Interfaces:
Cloneable,org.apache.camel.component.aws.common.AwsCommonConfiguration
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopy()software.amazon.awssdk.services.lambda.LambdaClientsoftware.amazon.awssdk.core.ProtocolbooleanbooleanbooleanbooleanbooleanbooleanvoidsetAccessKey(String accessKey) Amazon AWS Access KeyvoidsetAwsLambdaClient(software.amazon.awssdk.services.lambda.LambdaClient awsLambdaClient) To use an existing configured AwsLambdaClient clientvoidsetOperation(Lambda2Operations operation) The operation to perform.voidsetOverrideEndpoint(boolean overrideEndpoint) Set the need for overriding the endpoint.voidsetPojoRequest(boolean pojoRequest) If we want to use a POJO request as body or notvoidsetProfileCredentialsName(String profileCredentialsName) If using a profile credentials provider, this parameter will set the profile namevoidsetProxyHost(String proxyHost) To define a proxy host when instantiating the Lambda clientvoidsetProxyPort(Integer proxyPort) To define a proxy port when instantiating the Lambda clientvoidsetProxyProtocol(software.amazon.awssdk.core.Protocol proxyProtocol) To define a proxy protocol when instantiating the Lambda clientvoidThe region in which the Lambda client needs to work.voidsetSecretKey(String secretKey) Amazon AWS Secret KeyvoidsetSessionToken(String sessionToken) Amazon AWS Session Token used when the user needs to assume an IAM rolevoidsetTrustAllCertificates(boolean trustAllCertificates) If we want to trust all certificates in case of overriding the endpointvoidsetUriEndpointOverride(String uriEndpointOverride) Set the overriding uri endpoint.voidsetUseDefaultCredentialsProvider(Boolean useDefaultCredentialsProvider) Set whether the Lambda client should expect to load credentials through a default credentials provider or to expect static credentials to be passed in.voidsetUseProfileCredentialsProvider(boolean useProfileCredentialsProvider) Set whether the Lambda client should expect to load credentials through a profile credentials provider.voidsetUseSessionCredentials(boolean useSessionCredentials) Set whether the Lambda client should expect to use Session Credentials.
-
Constructor Details
-
Lambda2Configuration
public Lambda2Configuration()
-
-
Method Details
-
getAwsLambdaClient
public software.amazon.awssdk.services.lambda.LambdaClient getAwsLambdaClient() -
setAwsLambdaClient
public void setAwsLambdaClient(software.amazon.awssdk.services.lambda.LambdaClient awsLambdaClient) To use an existing configured AwsLambdaClient client -
getAccessKey
- Specified by:
getAccessKeyin interfaceorg.apache.camel.component.aws.common.AwsCommonConfiguration
-
setAccessKey
Amazon AWS Access Key -
getSecretKey
- Specified by:
getSecretKeyin interfaceorg.apache.camel.component.aws.common.AwsCommonConfiguration
-
setSecretKey
Amazon AWS Secret Key -
getSessionToken
- Specified by:
getSessionTokenin interfaceorg.apache.camel.component.aws.common.AwsCommonConfiguration
-
setSessionToken
Amazon AWS Session Token used when the user needs to assume an IAM role -
getRegion
- Specified by:
getRegionin interfaceorg.apache.camel.component.aws.common.AwsCommonConfiguration
-
setRegion
The region in which the Lambda client needs to work. When using this parameter, the configuration will expect the lowercase name of the region (for example, ap-east-1) You'll need to use the name Region.EU_WEST_1.id() -
getOperation
-
setOperation
The operation to perform. It can be listFunctions, getFunction, createFunction, deleteFunction or invokeFunction -
getProxyProtocol
public software.amazon.awssdk.core.Protocol getProxyProtocol()- Specified by:
getProxyProtocolin interfaceorg.apache.camel.component.aws.common.AwsCommonConfiguration
-
setProxyProtocol
public void setProxyProtocol(software.amazon.awssdk.core.Protocol proxyProtocol) To define a proxy protocol when instantiating the Lambda client -
getProxyHost
- Specified by:
getProxyHostin interfaceorg.apache.camel.component.aws.common.AwsCommonConfiguration
-
setProxyHost
To define a proxy host when instantiating the Lambda client -
getProxyPort
- Specified by:
getProxyPortin interfaceorg.apache.camel.component.aws.common.AwsCommonConfiguration
-
setProxyPort
To define a proxy port when instantiating the Lambda client -
isPojoRequest
public boolean isPojoRequest() -
setPojoRequest
public void setPojoRequest(boolean pojoRequest) If we want to use a POJO request as body or not -
isTrustAllCertificates
public boolean isTrustAllCertificates()- Specified by:
isTrustAllCertificatesin interfaceorg.apache.camel.component.aws.common.AwsCommonConfiguration
-
setTrustAllCertificates
public void setTrustAllCertificates(boolean trustAllCertificates) If we want to trust all certificates in case of overriding the endpoint -
isOverrideEndpoint
public boolean isOverrideEndpoint()- Specified by:
isOverrideEndpointin interfaceorg.apache.camel.component.aws.common.AwsCommonConfiguration
-
setOverrideEndpoint
public void setOverrideEndpoint(boolean overrideEndpoint) Set the need for overriding the endpoint. This option needs to be used in combination with the uriEndpointOverride option -
getUriEndpointOverride
- Specified by:
getUriEndpointOverridein interfaceorg.apache.camel.component.aws.common.AwsCommonConfiguration
-
setUriEndpointOverride
Set the overriding uri endpoint. This option needs to be used in combination with overrideEndpoint option -
setUseDefaultCredentialsProvider
Set whether the Lambda client should expect to load credentials through a default credentials provider or to expect static credentials to be passed in. -
isUseDefaultCredentialsProvider
public boolean isUseDefaultCredentialsProvider()- Specified by:
isUseDefaultCredentialsProviderin interfaceorg.apache.camel.component.aws.common.AwsCommonConfiguration
-
isUseProfileCredentialsProvider
public boolean isUseProfileCredentialsProvider()- Specified by:
isUseProfileCredentialsProviderin interfaceorg.apache.camel.component.aws.common.AwsCommonConfiguration
-
setUseProfileCredentialsProvider
public void setUseProfileCredentialsProvider(boolean useProfileCredentialsProvider) Set whether the Lambda client should expect to load credentials through a profile credentials provider. -
isUseSessionCredentials
public boolean isUseSessionCredentials()- Specified by:
isUseSessionCredentialsin interfaceorg.apache.camel.component.aws.common.AwsCommonConfiguration
-
setUseSessionCredentials
public void setUseSessionCredentials(boolean useSessionCredentials) Set whether the Lambda client should expect to use Session Credentials. This is useful in a situation in which the user needs to assume an IAM role for doing operations in Lambda. -
getProfileCredentialsName
- Specified by:
getProfileCredentialsNamein interfaceorg.apache.camel.component.aws.common.AwsCommonConfiguration
-
setProfileCredentialsName
If using a profile credentials provider, this parameter will set the profile name -
copy
-